﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.IO.Ports;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Threading;
using System.Runtime.InteropServices;
using System.Diagnostics;
using System.Text.RegularExpressions;
using Microsoft.Win32;

namespace SPP_Test_Executive_Project
{
    public partial class SPP_Test_Executive_Project : Form
    {
        public SPP_Test_Executive_Project()
        {
            InitializeComponent();
        }

        //Sting array to hold the Port names that match the VID = "403 PID = "6001"
        public string[] MatchingComPortList = new string[10];

        // Local Serial Port parameters From Properties Page
        public static string PortName = "COM4";
        public static string BaudRate = "115200";
        public static string DataBits = "8";
        public static string vParity = "None";
        public static string StopBits = "1";
        public static string pHandshake = "None";

        // This delegate enables asynchronous calls for setting
        // the text property on a TextBox control.
        delegate void DisplayCharactersCallback(string text);
        delegate void SendCharactersCallback(string text);

        // This thread is used to demonstrate both thread-safe and
        // unsafe ways to call a Windows Forms control.
        private Thread DisplayThread = null;
        private Thread SendThread = null;

        // Serial port 1 received string
        string CallGetDataChar;

        // Serial port send string
        char[] PutBuff;


        //Flag  for converting incoming stream to Hex
        public static bool HexConversion = false;
        public static int IdxHexChar = 0;
        public static bool hexConversionTabFlag = false;

        //Line Feed
        public static bool EchoTransmitCharacters = true;
        public static bool AppendLineFeed = false;

        // Main object loader
        private void STEP_Main_Load(object sender, System.EventArgs e)
        {

            //String buffer
            String PortText = "";

            //Index registers
            int Index = 0;

            // Get a list of serial port names.
            string[] ports;
            ports = SerialPort.GetPortNames();

                foreach (String port in ports)
                {
                        cmbDevList.Items.Add(port);
                }


        }


        private void SetButtonEnables()
        {
            btnOpenDevice.Enabled = true;
            btnCloseDevice.Enabled = false;

        }

        private void cmbDevList_SelectedIndexChanged(object sender, EventArgs e)
        {
            //Get Port name from Combo Box
            PortName = cmbDevList.Text;
        }

        private void btnOpenDevice_Click(object sender, EventArgs e)
        {
            OpenSerialPort1();

            lblDeviceConnected.Text = "Device Connected";
        }

        private void btnCloseDevice_Click(object sender, EventArgs e)
        {
            CloseSerialPort1();
            lblDeviceConnected.Text = "Dis-Connected";
        }


        //This is an alias to the Properties menu item under File
        //private void btnProperties_Click(object sender, EventArgs e)
        //{
        //ShowChildForm();
        //}

        //Open the Properties Window

        public void CloseSerialPort1()
        {
            //Check if serialPort1 is open, then close the serial port and window
            if (serialPort_STEP.IsOpen)
            {
                serialPort_STEP.Close();
            }
            btnOpenDevice.Enabled = true;
            btnCloseDevice.Enabled = false;
            //textBox1.ReadOnly = true;

        }

        public bool OpenSerialPort1()
        {
            try
            {
                //Set the serial port parameters
                serialPort_STEP.PortName = PortName;
                serialPort_STEP.BaudRate = Convert.ToInt32(BaudRate);
                serialPort_STEP.Parity = (Parity)Enum.Parse(typeof(Parity), vParity);
                serialPort_STEP.DataBits = Convert.ToInt16(DataBits);
                serialPort_STEP.StopBits = (StopBits)Enum.Parse(typeof(StopBits), StopBits);
                serialPort_STEP.Handshake = (Handshake)Enum.Parse(typeof(Handshake), pHandshake);

                if (!serialPort_STEP.IsOpen)
                {
                    serialPort_STEP.Open();
                    btnOpenDevice.Enabled = false;
                    btnCloseDevice.Enabled = true;
                    //textBox1.ReadOnly = false;
                    return true;
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
            return false;
        }

        private void btnReset_Click(object sender, EventArgs e)
        {
            Invalidate();
        }

        private void textBox1_KeyPress(object sender, KeyPressEventArgs e)
        {

            // If the port is closed, don't try to send a character.
            if (!serialPort_STEP.IsOpen) return;

            // If the port is Open, declare a char[] array with one element.
            PutBuff = new char[1];

            // Load element 0 with the key character.
            PutBuff[0] = e.KeyChar;

            // Send the one character buffer.
            this.SendThread = new Thread(new ThreadStart(this.CallPutData));
            this.SendThread.Start();

            // Set the KeyPress event as handled so the character won't
            // display locally. If you want it to display, omit the next line.
            e.Handled = EchoTransmitCharacters;
        }

        //CallPutData writes characters to the serial port
        //It can be used by thread safe calls.
        private void CallPutData()
        {
            //if (!AddLineFeedCharacter)
                serialPort_STEP.Write(PutBuff, 0, 1);
            //else
            //{
            //    if (PutBuff[0] == '\r')
            //    {
            //        serialPort_STEP.Write(PutBuff, 0, 1);
            //        Thread.Sleep(100);
            //        PutBuff[0] = '\n';
            //        serialPort_STEP.Write(PutBuff, 0, 1);
            //    }
            //}
        }

        private void serialPort_STEP_DataReceived(object sender, System.IO.Ports.SerialDataReceivedEventArgs e)
        {
            //dataready = true;
            //backgroundWorker1.RunWorkerAsync();
            this.Invoke(new EventHandler(CallGetData));
        }

        //CallGetData is invoked to process the data in the serial port 1 buffer
        private void CallGetData(object sender, EventArgs e)
        {
            while (serialPort_STEP.BytesToRead != 0)
            {
                //CallGetDataChar gets all characters in the serial port buffer.
                //Display thread is used to invoke a thread to display while not 
                //interrupting the reading of the serial port.
                CallGetDataChar = serialPort_STEP.ReadExisting();
                this.DisplayThread = new Thread(new ThreadStart(this.ThreadProcDisplay));
                DisplayThread.Start();

                //
            }
        }
        // This method is executed on the worker thread and makes
        // a thread-safe call on the TextBox control.
        private void ThreadProcDisplay()
        {
            //this.DisplayCharacters(Convert.ToChar(CallGetDataChar));
            this.DisplayCharacters(CallGetDataChar);

        }

        //DisplayCharacters() is thread safe method to display characters
        // from serial port on the main textbox
        private void DisplayCharacters(string text)
        {
            // InvokeRequired required compares the thread ID of the
            // calling thread to the thread ID of the creating thread.
            // If these threads are different, it returns true.
            if (this.textBox1.InvokeRequired)
            {
                DisplayCharactersCallback d = new DisplayCharactersCallback(DisplayCharacters);
                this.Invoke(d, new object[] { text });
            }
            else
            {
                if (HexConversion)
                {
                    //Perform a hex conversion on each char in the string and display it.
                    string HexChar;
                    foreach (char c in text)
                    {
                        int tmp = c;
                        HexChar = String.Format("{0:x2}", (uint)System.Convert.ToUInt32(tmp.ToString()));
                        if (c > 0x7f)
                            textBox1.AppendText("0x" + HexChar + " = 'Binary'");
                        else if (c > 0x20)
                            textBox1.AppendText("0x" + HexChar + " = '" + c + "'");
                        else
                        {
                            ASCII_To_Hex.Conversion asciiDecode;
                            asciiDecode = new ASCII_To_Hex.Conversion();
                            textBox1.AppendText("0x" + HexChar + " = '" + asciiDecode.HexMap(c) + "'");
                            hexConversionTabFlag = true;
                        }
                        if (IdxHexChar++ < 4)
                        {
                            if (hexConversionTabFlag)
                            {
                                textBox1.AppendText("\t");
                                hexConversionTabFlag = false;
                            }
                            else
                                textBox1.AppendText("\t\t");
                        }
                        else
                        {
                            textBox1.AppendText("\r\n");
                            IdxHexChar = 0;
                        }
                    }
                }
                else
                {
                    //If HexConversion is false display each char in string.

                    if (AppendLineFeed)
                    {
                        foreach (char c in text)
                        {
                            switch (c)
                            {
                                case '\n':
                                    this.textBox1.AppendText("\n");
                                    break;
                                case '\r':
                                    this.textBox1.AppendText("\r");
                                    break;
                                default:
                                    //this.textBox1.AppendText(text);
                                    break;
                            }
                        }
                        this.textBox1.AppendText(text);
                    }
                    else

                        this.textBox1.AppendText(text);
                }
            }
        }

        private void btnHexConv_Click(object sender, EventArgs e)
        {
            if (!HexConversion)
            {
                HexConversion = true;
                btnHexConv.Text = "HexOff";
            }
            else
            {
                HexConversion = false;
                btnHexConv.Text = "HexOn";
            }
        }

        private void btnLineFeed_Click(object sender, EventArgs e)
        {
            if (!AppendLineFeed)
                AppendLineFeed = true;
            else
                AppendLineFeed = false;
        }

        private void btnMotorForward_Click(object sender, EventArgs e)
        {
            byte address_to_device = 2;
            int intValue = Convert.ToInt32(tbMotorFwdCounts.Text);
            byte[] intBytes = BitConverter.GetBytes(intValue);
            //if (BitConverter.IsLittleEndian)
            //    Array.Reverse(intBytes);
            byte[] ibyte = intBytes;

            //Send LSB of the Motor count to the L552
            MDT_AH_SendByte(address_to_device, ibyte[0]);
            //Delay 1ms then send the Trigger 0x01 to latch in the byte
            Thread.Sleep(1);
            MDT_AH_SendTrigger(0x01);
            //Send LSB of the Motor count to the L552
            MDT_AH_SendByte(address_to_device, ibyte[1]);
            //Delay 1ms then send the Trigger 0x02 to latch in the second byte
            Thread.Sleep(1);
            MDT_AH_SendTrigger(0x02);
            //Send MSB of the Motor count to the L552
            MDT_AH_SendByte(address_to_device, ibyte[2]);
            //Delay 1ms then send the Trigger 0x01 to latch in the third byte
            Thread.Sleep(1);
            MDT_AH_SendTrigger(0x04);

            //Send the start motor movement using Trigger 0x10
            Thread.Sleep(1);
            MDT_AH_SendTrigger(0x10);

        }

        private void btnMotorRewind_Click(object sender, EventArgs e)
        {
            byte address_to_device = 2;
            int intValue = Convert.ToInt32(tbMotorReverse.Text);
            byte[] intBytes = BitConverter.GetBytes(intValue);
            //if (BitConverter.IsLittleEndian)
            //    Array.Reverse(intBytes);
            byte[] ibyte = intBytes;

            //Send LSB of the Motor count to the L552
            MDT_AH_SendByte(address_to_device, ibyte[0]);
            //Delay 1ms then send the Trigger 0x01 to latch in the byte
            Thread.Sleep(1);
            MDT_AH_SendTrigger(0x01);
            //Send LSB of the Motor count to the L552
            MDT_AH_SendByte(address_to_device, ibyte[1]);
            //Delay 1ms then send the Trigger 0x02 to latch in the second byte
            Thread.Sleep(1);
            MDT_AH_SendTrigger(0x02);
            //Send MSB of the Motor count to the L552
            MDT_AH_SendByte(address_to_device, ibyte[2]);
            //Delay 1ms then send the Trigger 0x01 to latch in the third byte
            Thread.Sleep(1);
            MDT_AH_SendTrigger(0x04);

            //Send the start motor movement using Trigger 0x20
            Thread.Sleep(1);
            MDT_AH_SendTrigger(0x11);

        }

        private void btnClearTextBox_Click(object sender, EventArgs e)
        {
            textBox1.Clear();
        }

        private void groupBox1_Enter(object sender, EventArgs e)
        {

        }
    }
}
