/*****************************************************
 * $Workfile::                                       
 * $Author::	RJolly                                         
 * $Date::    	8/22/2019                                       
 * $Revision::   	002                                    
 *
 * Copyright Earth People Technology, Inc. 2019
 *
 * This header files defines the input/output
 *	8/22/19	Created 
		
******************************************************/
`ifndef _TOP_UC_CONTROLLER_DEFINE
 `define _TOP_UC_CONTROLLER_DEFINE


    //////////////////////////////////////////////////////
    //  UC MEMORY MAP LOCATIONS
    //////////////////////////////////////////////////////
    //Memory Location for ADC CONVST Delay Value Bytes 1, 2, and 3
    `define ADC_CONVST_DLY_1_MEMORY_LOCATION      8'h00
    `define ADC_CONVST_DLY_2_MEMORY_LOCATION      8'h01
    `define ADC_CONVST_DLY_3_MEMORY_LOCATION      8'h02

	//Memory Location for I2C_0 
    `define I2C_0_WRITE_A_CMD_MEMORY_LOCATION    8'h03
    `define I2C_0_WRITE_A_DATA_MEMORY_LOCATION   8'h04
    `define I2C_0_READ_A_DATA1_MEMORY_LOCATION   8'h05
    `define I2C_0_READ_A_DATA2_MEMORY_LOCATION   8'h06
	
	//Memory Location for I2C_1 
    `define I2C_1_WRITE_B_CMD_MEMORY_LOCATION    8'h07
    `define I2C_1_WRITE_B_DATA_MEMORY_LOCATION   8'h08
    `define I2C_1_READ_B_DATA1_MEMORY_LOCATION   8'h09
    `define I2C_1_READ_B_DATA2_MEMORY_LOCATION   8'h0a

	//Memory Location for TMP102 on the I2C bus 
    `define TMP102_CMD_MEMORY_LOCATION    8'h03
    `define TMP102_DATA_MEMORY_LOCATION   8'h05
	
    //////////////////////////////////////////////////////
    //  DSO CONTROL REGISTERS
    //////////////////////////////////////////////////////
	//ADDRESS                   FUNCTION              BITS
    //0x0                       ADC Control           0 - Start ADC Conversions
	//                                                1 - 
	//                                                2 - 
	//                                                3 - Stop ADC Conversion
	//                                                4 - adc_scan_channel_1
	//                                                5 - adc_scan_channel_2
	//                                                6 - adc_scan_channel_3
	//                                                7 - adc_scan_channel_4
    //0x01                      SPI Control           0 - Write to PGA Channel 1 (Contents of Memory location 0x10)
	//                                                1 - Write to PGA Channel 2 (Contents of Memory location 0x12)
	//                                                2 - Write to PGA Channel 3 (Contents of Memory location 0x14)
	//                                                3 - Write to PGA Channel 4 (Contents of Memory location 0x16)
	//                                                4 - Read from PGA Channel 1 (Add Contents to Memory location 0x1a)
	//                                                5 - Read from PGA Channel 2 (Add Contents to Memory location 0x1a)
	//                                                6 - Read from PGA Channel 3 (Add Contents to Memory location 0x1a)
	//                                                7 - Read from PGA Channel 4 (Add Contents to Memory location 0x1a)
    //0x02                      I2C - 0 Control       0 - 
	//                                                1 - 
	//                                                2 - 
	//                                                3 - 
	//                                                4 - 
	//                                                5 - 
	//                                                6 - 
	//                                                7 - 
    //0x03                      I2C - 1 Control       0 - 
	//                                                1 - 
	//                                                2 - 
	//                                                3 - 
	//                                                4 - 
	//                                                5 - 
	//                                                6 - 
	//                                                7 - 
    //0x04       ADC CONVST Delay Value Control       0 - Update the adc_convst_delay_value register
	//                                                1 - 
	//                                                2 - 
	//                                                3 - 
	//                                                4 - 
	//                                                5 - 
	//                                                6 - 
	//                                                7 - 
    //0x05       Reset Control                        0 - Issue a software reset (Self Resetting Bit)
	//                                                1 - 
	//                                                2 - 
	//                                                3 - 
	//                                                4 - 
	//                                                5 - 
	//                                                6 - 
	//                                                7 - 

    //////////////////////////////////////////////////////
    //  DSO CONTROL REGISTER Bits
    //////////////////////////////////////////////////////

	//ADC CONVST Delay Register Commands
    `define ADC_CONVST_DELAY_COMMAND              8'h10
 

    //Memory Read Cycle, Wait States for MEMORY_RD_DATA
    `define MEMORY_RD_LATCH_WAIT_STATE	          8'h05
    `define MEMORY_RD_COMPLETE_WAIT_STATE	      8'h0a

    //////////////////////////////////////////////////////
    //  DSO Commands
    //////////////////////////////////////////////////////

    //PGA Commands
    `define PGA_WRITE_COMMAND                     8'h2a
    `define PGA_READ_COMMAND                      8'h3a
	
    //I2C Bus 0 Commands
    `define I2C_WRITE_COMMAND                     1'h0
    `define I2C_READ_COMMAND                      1'h1
	
	//MCP4451 Commands
    `define MCP4451_CHIP_2_FIXED_ADDRESS          7'h2c //8'h58

     //TMP102 Commands
    `define TMP102_FIXED_ADDRESS                  8'h90  //TMP102 base address is 7'b1001000
    `define TMP102_WRITE_TO_TEMP_REG              4'h8
    `define TMP102_WRITE_TO_CONFIG_REG            4'h9
    `define TMP102_READ_FROM_TEMP_REG             4'ha
    `define TMP102_READ_FROM_CONFIG_REG           4'hb

    //TMP102 Registers
    `define TMP102_TEMPERATURE_REGISTER           8'h0
    `define TMP102_CONFIG_REGISTER                8'h01
	
	
    //Memory Read Wait States
    `define MEMORY_RD_WAIT_STATES                 8'h03 
	
    //ADC Multiplexor Commands
    `define ADC_MUX_CH4                           4'b1110
    `define ADC_MUX_CH1                           4'b1101
    `define ADC_MUX_CH2                           4'b1011
    `define ADC_MUX_CH3                           4'b0111
    `define ADC_MUX_OFF                           4'b1111

`endif //  `ifndef _TOP_DEFINE

