//#######################################################################
//#
//#	Copyright 	Earth People Technology Inc. 2012
//#
//#
//# File Name:  ept_2232h_top.v
//# Author:     R. Jolly
//# Date:       March 23, 2012
//# Revision:   A
//#
//# Development: USB Test Tool Interface board 
//# Application: Xilinx Spartan 3
//# Description: This file contains verilog code which will allow access
//#              to an eight bit bus in the FPGA. The FPGA receives its commands via
//#				 USB.
//#               
//#              
//#
//#************************************************************************
//#
//# Revision History:	
//#			DATE		VERSION		DETAILS		
//#			03/23/12 	A			Created			RJJ
//#
//#									
//#
//#######################################################################


//************************************************************************
//* Module Declaration
//************************************************************************

module ept_2232h_top (

	
	input wire                 CLK,
	input wire                 RST,
		
    // UART Signals
	output wire                UART_OUT,
	input wire                 UART_IN,
		
    // FTDI Control Signals
	input wire                 FTDI_RXF,
	input wire                 FTDI_TXE,
    inout wire [7:0]           FTDI_DATA,

	output wire                FTDI_RD,
	output wire                FTDI_WR,
	output wire                FTDI_SI,
	
	//Transceiver Control Signals
	output wire                TR_DIR_1,
	output wire                TR_OE_1,
	output wire                TR_DIR_2,
	output wire                TR_OE_2,
	output wire                TR_DIR_3,
	output wire                TR_OE_3,
	
	//Unused signals
	input wire [7:0]           LB_LOWER,
	input wire [7:0]          LB_MIDDLE,
	input wire [5:0]           LB_UPPER

	);

	
	
//***************************************************************************
//* Internal Signals and Registers Declarations
//***************************************************************************
		
	//Reset Registers
	wire                       reset_n;
	wire                       global_reset;
	
	
//***************************************************************************
//* 	Signal Assignments	
//***************************************************************************

    assign          reset_n = !RST;
	assign          global_reset = RST;
	
	
//***************************************************************************
//* 	Leaf Instantiations	
//***************************************************************************
 
   uart_tiny_slave UART_SLAVE_CONTROLLER
   (
     .CLK                      (CLK),
     .RST_N                    (global_reset),

     .UART_OUT                 (UART_OUT), //To external UART 
     .UART_IN                  (UART_IN), //From external UART

	.USB_RXF_N                 (FTDI_RXF),
	.USB_TXE_N                 (FTDI_TXE),
	.USB_DATA                  (FTDI_DATA),

	.USB_RD_N                  (FTDI_RD),
	.USB_WR                    (FTDI_WR),
	.USB_SI                    (FTDI_SI),

	.TR_DIR_1                  (TR_DIR_1),
	.TR_OE_1                   (TR_OE_1),
	.TR_DIR_2                  (TR_DIR_2),
	.TR_OE_2                   (TR_OE_2),
	.TR_DIR_3                  (TR_DIR_3),
	.TR_OE_3                   (TR_OE_3)
	);
   endmodule
